==> qtjambi-help-6.2.5-sources.jar: io/qt/help/QHelpFilterSettingsWidget.java <==
package io.qt.help;


/**
 * <p>Widget that allows for creating, editing and removing filters</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html">QHelpFilterSettingsWidget</a></p>
 */
public class QHelpFilterSettingsWidget extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpFilterSettingsWidget.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QHelpFilterSettingsWidget(io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QHelpFilterSettingsWidget() {
        this((io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#QHelpFilterSettingsWidget">QHelpFilterSettingsWidget::QHelpFilterSettingsWidget(QWidget*)</a></p>
     */
    public QHelpFilterSettingsWidget(io.qt.widgets.QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QHelpFilterSettingsWidget instance, io.qt.widgets.QWidget parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#applySettings">QHelpFilterSettingsWidget::applySettings(QHelpFilterEngine*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean applySettings(io.qt.help.QHelpFilterEngine filterEngine){
        return applySettings_native_QHelpFilterEngine_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterEngine));
    }
    
    @io.qt.QtUninvokable
    private native boolean applySettings_native_QHelpFilterEngine_ptr_constfct(long __this__nativeId, long filterEngine);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#readSettings">QHelpFilterSettingsWidget::readSettings(const QHelpFilterEngine*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void readSettings(io.qt.help.QHelpFilterEngine filterEngine){
        readSettings_native_const_QHelpFilterEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterEngine));
    }
    
    @io.qt.QtUninvokable
    private native void readSettings_native_const_QHelpFilterEngine_ptr(long __this__nativeId, long filterEngine);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#setAvailableComponents">QHelpFilterSettingsWidget::setAvailableComponents(QStringList)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setAvailableComponents(java.util.Collection<java.lang.String> components){
        setAvailableComponents_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), components);
    }
    
    @io.qt.QtUninvokable
    private native void setAvailableComponents_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> components);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#setAvailableVersions">QHelpFilterSettingsWidget::setAvailableVersions(QList&lt;QVersionNumber&gt;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setAvailableVersions(java.util.Collection<? extends io.qt.core.QVersionNumber> versions){
        setAvailableVersions_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), versions);
    }
    
    @io.qt.QtUninvokable
    private native void setAvailableVersions_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.core.QVersionNumber> versions);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpFilterSettingsWidget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QHelpFilterSettingsWidget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QHelpFilterSettingsWidget instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-help-6.4.0-sources.jar: io/qt/help/QHelpFilterSettingsWidget.java <==
package io.qt.help;


/**
 * <p>Widget that allows for creating, editing and removing filters</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html">QHelpFilterSettingsWidget</a></p>
 */
public class QHelpFilterSettingsWidget extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpFilterSettingsWidget.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QHelpFilterSettingsWidget(io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QHelpFilterSettingsWidget() {
        this((io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#QHelpFilterSettingsWidget">QHelpFilterSettingsWidget::QHelpFilterSettingsWidget(QWidget*)</a></p>
     */
    public QHelpFilterSettingsWidget(io.qt.widgets.QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QHelpFilterSettingsWidget instance, io.qt.widgets.QWidget parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#applySettings">QHelpFilterSettingsWidget::applySettings(QHelpFilterEngine*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean applySettings(io.qt.help.QHelpFilterEngine filterEngine){
        return applySettings_native_QHelpFilterEngine_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterEngine));
    }
    
    @io.qt.QtUninvokable
    private native boolean applySettings_native_QHelpFilterEngine_ptr_constfct(long __this__nativeId, long filterEngine);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#readSettings">QHelpFilterSettingsWidget::readSettings(const QHelpFilterEngine*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void readSettings(io.qt.help.QHelpFilterEngine filterEngine){
        readSettings_native_const_QHelpFilterEngine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterEngine));
    }
    
    @io.qt.QtUninvokable
    private native void readSettings_native_const_QHelpFilterEngine_ptr(long __this__nativeId, long filterEngine);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#setAvailableComponents">QHelpFilterSettingsWidget::setAvailableComponents(QStringList)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setAvailableComponents(java.util.Collection<java.lang.String> components){
        setAvailableComponents_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), components);
    }
    
    @io.qt.QtUninvokable
    private native void setAvailableComponents_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> components);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpfiltersettingswidget.html#setAvailableVersions">QHelpFilterSettingsWidget::setAvailableVersions(QList&lt;QVersionNumber&gt;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setAvailableVersions(java.util.Collection<? extends io.qt.core.QVersionNumber> versions){
        setAvailableVersions_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), versions);
    }
    
    @io.qt.QtUninvokable
    private native void setAvailableVersions_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.core.QVersionNumber> versions);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpFilterSettingsWidget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QHelpFilterSettingsWidget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QHelpFilterSettingsWidget instance, QDeclarativeConstructor constructor);
    
}
